from xml.etree import ElementTree
import sys
import random
import uuid


def new_guid():
    return uuid.uuid4().hex


def createReal(value):
    real = ElementTree.Element('real')
    real.set('value', str(value))

    return real


def createAngle(value):
    angle = ElementTree.Element('angle')
    angle.set('value', str(value))

    return angle


def createVector(xValue, yValue):
    vector = ElementTree.Element('vector')

    x = ElementTree.SubElement(vector, 'x')
    x.text = str(xValue)

    y = ElementTree.SubElement(vector, 'y')
    y.text = str(yValue)

    return vector


def createReciprocal(toLink, linkExported=None, type='real'):
    reciprocal = ElementTree.Element('reciprocal')
    reciprocal.set('type', type)
    if linkExported is not None:
        reciprocal.set('link', linkExported)

    if linkExported is None:
        link = ElementTree.SubElement(reciprocal, 'link')
        link.append(toLink)

    epsilon = ElementTree.SubElement(reciprocal, 'epsilon')
    epsilon.append(createReal("0.0000010000"))

    infinite = ElementTree.SubElement(reciprocal, 'infinite')
    infinite.append(createReal(999999.0000000000))

    return reciprocal


def createScale(scalarLink, type=None, linkExported=None, toLink=None):
    scale = ElementTree.Element('scale')
    scale.set('type', str(type))
    if linkExported is not None:
        scale.set('link', linkExported)

    if linkExported is None:
        link = ElementTree.SubElement(scale, 'link')
        link.append(toLink)

    scalar = ElementTree.SubElement(scale, 'scalar')
    scalar.append(scalarLink)

    return scale


def createSubtract(lhsLink, rhsLink, scalarLink, type):
    subtract = ElementTree.Element('subtract')
    subtract.set('type', type)

    scalar = ElementTree.SubElement(subtract, 'scalar')
    scalar.append(scalarLink)

    lhs = ElementTree.SubElement(subtract, 'lhs')
    lhs.append(lhsLink)

    rhs = ElementTree.SubElement(subtract, 'rhs')
    rhs.append(rhsLink)

    return subtract


def createAdd(lhsLink, rhsLink, scalarLink, type):
    add = ElementTree.Element('add')
    add.set('type', type)

    lhs = ElementTree.SubElement(add, 'lhs')
    lhs.append(lhsLink)

    rhs = ElementTree.SubElement(add, 'rhs')
    rhs.append(rhsLink)

    scalar = ElementTree.SubElement(add, 'scalar')
    scalar.append(scalarLink)

    return add


def createRange(minLink, maxLink, toLink, type, linkExported=None):
    range = ElementTree.Element('range')
    range.set('type', type)
    if linkExported is not None:
        range.set('link', linkExported)

    min = ElementTree.SubElement(range, 'min')
    min.append(minLink)

    max = ElementTree.SubElement(range, 'max')
    max.append(maxLink)

    if linkExported is None:
        link = ElementTree.SubElement(range, 'link')
        link.append(toLink)

    return range


def createPower(type, baseLink, powerRLink):
    power = ElementTree.Element('power')
    power.set('type', type)

    base = ElementTree.SubElement(power, 'base')
    base.append(baseLink)

    powerR = ElementTree.SubElement(power, 'power')
    powerR.append(powerRLink)

    epsilon = ElementTree.SubElement(power, 'epsilon')
    epsilon.append(createReal("0.0000010000"))

    infinite = ElementTree.SubElement(power, 'infinite')
    infinite.append(createReal("999999.0000000000"))

    return power


def connectController(typeTransition, list, controllerX, controllerY, list2=None):
    transitionList = []
    if(len(list) > 4):
      if(typeTransition == "vector"):
          transitionList.append(createVector(list[0], list2[0]))
          transitionList.append(createVector(list[1]-list[0], list2[1]-list2[0]))
          transitionList.append(createVector(list[3]-list[0], list2[3]-list2[0]))
          transitionList.append(createVector(list[2]-list[0], list2[2]-list2[0]))
          transitionList.append(createVector(list[4]-list[0], list2[4]-list2[0]))
      elif(typeTransition == "real"):
          transitionList.append(createReal(list[0]))
          transitionList.append(createReal(list[1]-list[0]))
          transitionList.append(createReal(list[3]-list[0]))
          transitionList.append(createReal(list[2]-list[0]))
          transitionList.append(createReal(list[4]-list[0]))
      elif(typeTransition == "angle"):
          transitionList.append(createAngle(list[0]))
          transitionList.append(createAngle(list[1]-list[0]))
          transitionList.append(createAngle(list[3]-list[0]))
          transitionList.append(createAngle(list[2]-list[0]))
          transitionList.append(createAngle(list[4]-list[0]))
      myxm = createAdd(
          type=typeTransition,
          lhsLink=createAdd(
              scalarLink=createReal(1.0),
              type=typeTransition,
              lhsLink=createAdd(
                  scalarLink=createReal(1.0),
                  type=typeTransition,
                  lhsLink=transitionList[0],
                  rhsLink=createScale(
                      type=typeTransition,
                      toLink=transitionList[1],
                      scalarLink=createRange(
                          type='real',
                          minLink=createReal(0),
                          maxLink=createReal(1.00),
                          toLink=createSubtract(
                              type='real',
                              scalarLink=createReciprocal(
                                  toLink=createReal(100),
                                  type="real"
                              ),
                              lhsLink=createScale(
                                  type="real",
                                  linkExported=controllerX,
                                  scalarLink=createReal(60.0)
                              ),
                              rhsLink=createReal(0)
                          )
                      )
                  )
              ),
              rhsLink=createScale(
                  type=typeTransition,
                  toLink=transitionList[2],
                  scalarLink=createRange(
                      type="real",
                      minLink=createReal("0.0"),
                      maxLink=createReal("1.00000"),
                      toLink=createSubtract(
                          type="real",
                          scalarLink=createReciprocal(
                              type='real',
                              toLink=createReal('100.000')
                          ),
                          lhsLink=createScale(
                              type='real',
                              linkExported=controllerY,
                              scalarLink=createReal("60.0")
                          ),
                          rhsLink=createReal("0")
                      )
                  )
              )
          ),
          rhsLink=createAdd(
              type=typeTransition,
              lhsLink=createScale(
                  type=typeTransition,
                  toLink=transitionList[3],
                  scalarLink=createSubtract(
                      type='real',
                      scalarLink=createReciprocal(
                          type='real',
                          toLink=createReal(-100)
                      ),
                      lhsLink=createRange(
                          type="real",
                          minLink=createReal(-100),
                          maxLink=createReal(0),
                          toLink=createScale(
                              type='real',
                              linkExported=controllerX,
                              scalarLink=createReal(60)
                          )
                      ),
                      rhsLink=createReal(0)
                  )
              ),
              rhsLink=createScale(
                  type=typeTransition,
                  toLink=transitionList[4],
                  scalarLink=createSubtract(
                      type='real',
                      scalarLink=createReciprocal(
                          type='real',
                          toLink=createReal(-100),
                      ),
                      lhsLink=createRange(
                          type='real',
                          minLink=createReal(-100.0000000000),
                          maxLink=createReal(0),
                          toLink=createScale(
                              type='real',
                              linkExported=controllerY,
                              scalarLink=createReal(60.0)
                          )
                      ),
                      rhsLink=createReal(0)
                  ),
              ),
              scalarLink=createReal(1.0)
          ),
          scalarLink=createReal(1.0),
      )
      return myxm


def createController(root):
    for item in root:
        if item.tag == "defs":
            exportedDefs = item
    try:
      exportedDefs
    except NameError:
      exportedDefs = ElementTree.Element('defs')
      root.insert(list(root).index(list(root.findall(".//layer"))[0]) - 1, exportedDefs)
      
    print(len(list(exportedDefs)))
    controllerId = random.randint(0, 9999)
    controller = ElementTree.fromstring(
        '''<composite type="vector" x="controllerX{id}" y="controllerY{id}" id="controller{id}"/>'''.format(id=controllerId))
    controllerX = ElementTree.fromstring(
        ''' <real value="0" id="controllerX{id}"/>'''.format(id=controllerId))
    controllerY = ElementTree.fromstring(
        '''    <real value="0" id="controllerY{id}"/>'''.format(id=controllerId))
    controlElements = [controller, controllerX, controllerY]
    exportedDefs.extend(controlElements)
    drawController(root, "controller" + str(controllerId))
    return "controllerY" + str(controllerId), "controllerX" + str(controllerId)


def drawController(root, controllerId):
    controllerLayer = ElementTree.fromstring(f'''  
    <layer type="group" active="true" exclude_from_rendering="true" version="0.3" desc="Controller">
    <param name="z_depth">
      <real value="0.0000000000"/>
    </param>
    <param name="amount">
      <real value="1.0000000000"/>
    </param>
    <param name="blend_method">
      <integer value="0"/>
    </param>
    <param name="origin">
      <vector>
        <x>0.0000000000</x>
        <y>0.0000000000</y>
      </vector>
    </param>
    <param name="transformation">
      <composite type="transformation">
        <offset>
          <add type="vector">
            <lhs>
              <vector>
                <x>0.0000000000</x>
                <y>0.0000000000</y>
              </vector>
            </lhs>
            <rhs>
              <vector>
                <x>0.0000000000</x>
                <y>0.0000000000</y>
              </vector>
            </rhs>
            <scalar>
              <real value="1.0000000000"/>
            </scalar>
          </add>
        </offset>
        <angle>
          <angle value="0.000000"/>
        </angle>
        <skew_angle>
          <angle value="0.000000"/>
        </skew_angle>
        <scale>
          <scale type="vector">
            <link>
              <vector>
                <x>1.0000000000</x>
                <y>1.0000000000</y>
              </vector>
            </link>
            <scalar>
              <exp type="real">
                <exp>
                  <real value="0.0000000000"/>
                </exp>
                <scale>
                  <real value="1.0000000000"/>
                </scale>
              </exp>
            </scalar>
          </scale>
        </scale>
      </composite>
    </param>
    <param name="canvas">
      <canvas xres="10.000000" yres="10.000000">
        <layer type="advanced_outline" active="true" exclude_from_rendering="false" version="0.3" desc="Outline">
          <param name="z_depth">
            <real value="0.0000000000"/>
          </param>
          <param name="amount">
            <real value="1.0000000000"/>
          </param>
          <param name="blend_method">
            <integer value="0" static="true"/>
          </param>
          <param name="color">
            <color>
              <r>0.000000</r>
              <g>0.000000</g>
              <b>0.000000</b>
              <a>1.000000</a>
            </color>
          </param>
          <param name="origin">
            <vector>
              <x>0.0000000000</x>
              <y>0.0000000000</y>
            </vector>
          </param>
          <param name="invert">
            <bool value="false"/>
          </param>
          <param name="antialias">
            <bool value="true"/>
          </param>
          <param name="feather">
            <real value="0.0000000000"/>
          </param>
          <param name="blurtype">
            <integer value="1"/>
          </param>
          <param name="winding_style">
            <integer value="0"/>
          </param>
          <param name="bline">
            <bline guid="{new_guid()}" type="bline_point" loop="true">
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>-1.1284407377</x>
                      <y>1.9541293383</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="1.3722948075"/>
                      </radius>
                      <theta>
                        <angle value="0.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="-180.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>-1.1284407377</x>
                      <y>1.9541293383</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="0.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="-180.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>1.1284409761</x>
                      <y>1.9541293383</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="0.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="1.3722944296"/>
                      </radius>
                      <theta>
                        <angle value="0.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>1.9541296959</x>
                      <y>1.1284404993</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="1.3722949965"/>
                      </radius>
                      <theta>
                        <angle value="-90.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="-180.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>1.9541296959</x>
                      <y>-1.1284407377</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="0.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="1.3722944296"/>
                      </radius>
                      <theta>
                        <angle value="-90.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>1.1284409761</x>
                      <y>-1.9541293383</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="1.3722944296"/>
                      </radius>
                      <theta>
                        <angle value="180.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="-180.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>-1.1284407377</x>
                      <y>-1.9541293383</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="0.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="1.3722948075"/>
                      </radius>
                      <theta>
                        <angle value="-180.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>-1.9541296959</x>
                      <y>-1.1284407377</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="1.3722944296"/>
                      </radius>
                      <theta>
                        <angle value="90.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="-180.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="bline_point">
                  <point>
                    <vector>
                      <x>-1.9541296959</x>
                      <y>1.1284404993</y>
                    </vector>
                  </point>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <origin>
                    <real value="0.5000000000"/>
                  </origin>
                  <split>
                    <bool value="true"/>
                  </split>
                  <t1>
                    <radial_composite type="vector">
                      <radius>
                        <real value="0.0000000000"/>
                      </radius>
                      <theta>
                        <angle value="0.000000"/>
                      </theta>
                    </radial_composite>
                  </t1>
                  <t2>
                    <radial_composite type="vector">
                      <radius>
                        <real value="1.3722949965"/>
                      </radius>
                      <theta>
                        <angle value="-270.000000"/>
                      </theta>
                    </radial_composite>
                  </t2>
                  <split_radius>
                    <bool value="true"/>
                  </split_radius>
                  <split_angle>
                    <bool value="true"/>
                  </split_angle>
                </composite>
              </entry>
            </bline>
          </param>
          <param name="width">
            <real value="0.1668139470"/>
          </param>
          <param name="expand">
            <real value="0.0000000000"/>
          </param>
          <param name="start_tip">
            <integer value="1"/>
          </param>
          <param name="end_tip">
            <integer value="1"/>
          </param>
          <param name="cusp_type">
            <integer value="0"/>
          </param>
          <param name="smoothness">
            <real value="1.0000000000"/>
          </param>
          <param name="homogeneous">
            <bool value="true" static="true"/>
          </param>
          <param name="wplist">
            <wplist type="width_point" loop="false">
              <entry>
                <composite guid="{new_guid()}" type="width_point">
                  <position>
                    <real value="0.1000000000"/>
                  </position>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <side_before>
                    <integer value="0"/>
                  </side_before>
                  <side_after>
                    <integer value="0"/>
                  </side_after>
                  <lower_bound>
                    <real value="0.0000000000" static="true"/>
                  </lower_bound>
                  <upper_bound>
                    <real value="1.0000000000" static="true"/>
                  </upper_bound>
                </composite>
              </entry>
              <entry>
                <composite guid="{new_guid()}" type="width_point">
                  <position>
                    <real value="0.9000000000"/>
                  </position>
                  <width>
                    <real value="1.0000000000"/>
                  </width>
                  <side_before>
                    <integer value="0"/>
                  </side_before>
                  <side_after>
                    <integer value="0"/>
                  </side_after>
                  <lower_bound>
                    <real value="0.0000000000" static="true"/>
                  </lower_bound>
                  <upper_bound>
                    <real value="1.0000000000" static="true"/>
                  </upper_bound>
                </composite>
              </entry>
            </wplist>
          </param>
          <param name="dash_enabled">
            <bool value="true"/>
          </param>
          <param name="dilist">
            <dilist type="dash_item" loop="false">
              <entry>
                <composite guid="{new_guid()}" type="dash_item">
                  <offset>
                    <real value="0.1000000000"/>
                  </offset>
                  <length>
                    <real value="0.5000000000"/>
                  </length>
                  <side_before>
                    <integer value="4"/>
                  </side_before>
                  <side_after>
                    <integer value="4"/>
                  </side_after>
                </composite>
              </entry>
            </dilist>
          </param>
          <param name="dash_offset">
            <real value="0.0000000000"/>
          </param>
        </layer>
        <layer type="circle" active="true" exclude_from_rendering="false" version="0.2" desc="Circle070">
          <param name="z_depth">
            <real value="0.0000000000"/>
          </param>
          <param name="amount">
            <real value="1.0000000000"/>
          </param>
          <param name="blend_method">
            <integer value="0"/>
          </param>
          <param name="color">
            <color>
              <r>1.000000</r>
              <g>0.039947</g>
              <b>0.487765</b>
              <a>1.000000</a>
            </color>
          </param>
          <param name="radius">
            <real value="0.4170348676"/>
          </param>
          <param name="feather">
            <real value="0.0000000000"/>
          </param>
          <param name="origin" use=":{controllerId}"/>
          <param name="invert">
            <bool value="false"/>
          </param>
        </layer>
      </canvas>
    </param>
    <param name="time_dilation">
      <real value="1.0000000000"/>
    </param>
    <param name="time_offset">
      <time value="0s"/>
    </param>
    <param name="children_lock">
      <bool value="false"/>
    </param>
    <param name="outline_grow">
      <real value="0.0000000000"/>
    </param>
    <param name="z_range">
      <bool value="false" static="true"/>
    </param>
    <param name="z_range_position">
      <real value="0.0000000000"/>
    </param>
    <param name="z_range_depth">
      <real value="0.0000000000"/>
    </param>
    <param name="z_range_blur">
      <real value="0.0000000000"/>
    </param>
  </layer>
''')
    root.append(controllerLayer)


root = ElementTree.parse(sys.argv[1]).getroot()

# Create new exported value controller
print(root.attrib['width'])
print(root.attrib['height'])
viewBox = list(map(lambda x: float(x), root.attrib['view-box'].split(' ')))
center = [((viewBox[0] + viewBox[2]) / 2), ((viewBox[1] + viewBox[3]) / 2)]
print(center)
controllerY, controllerX  = createController(root)

for parameters in root.findall(".//*/animated[@type='vector']/.."):
    for values in parameters:
        if(values.tag == "animated"):
            originXs = []
            originYs = []
            for waypoint in values.findall("waypoint"):
                originXs.append(float(waypoint[0][0].text))
                originYs.append(float(waypoint[0][1].text))
            myxm = connectController(
                typeTransition="vector", list=originXs, list2=originYs, controllerX=controllerX, controllerY=controllerY)
            if(myxm is not None):
              parameters.remove(parameters[0])
              parameters.append(myxm)

for parameters in root.findall(".//*/animated[@type='real']/.."):
    for values in parameters:
        if(values.tag == "animated"):
            realValues = []
            for waypoint in values.findall("waypoint"):
                realValues.append(float(waypoint[0].attrib['value']))
            myxm = connectController(typeTransition='real', list=realValues, controllerX=controllerX, controllerY=controllerY)
            if(myxm is not None):
              parameters.remove(parameters[0])
              parameters.append(myxm)

for parameters in root.findall(".//*/animated[@type='angle']/.."):
    for values in parameters:
        if(values.tag == "animated"):
            waypointAngles = []
            for waypoint in values.findall("waypoint"):
                waypointAngles.append(float(waypoint[0].attrib['value']))
            myxm = connectController(
                typeTransition="angle", list=waypointAngles, controllerX=controllerX, controllerY=controllerY)
            if(myxm is not None):
              parameters.remove(parameters[0])
              parameters.append(myxm)

writeTo = sys.argv[2] if len(sys.argv) > 2 else sys.argv[1]

with open(writeTo, "wb") as files:
    files.write(ElementTree.tostring(root))
